==> currents-api-types-0.0.18.tgz: package/mixspace/parsers.ts <==
import { z, ZodType } from 'zod';
import { firestoreListParamsParser } from '../common/parsers/queryParams';
import { MIXSPACE_ID_PARAM_NAME } from './route.constants';
import { Mixspace } from './types';
import { MixspaceId } from './id.types';
import { UUID_SEPARATOR } from '../utils/uuid';
import { MIXSPACE_ITEM_TYPE_APPLE, MIXSPACE_ITEM_TYPE_CHANNEL, MIXSPACE_ITEM_TYPES } from './constants';
import { channelIdParser } from '../channel/parsers';
import { mixspaceIdParser } from './parsers.id';

export const mixspaceListQueryParser = firestoreListParamsParser;
export const mixspaceListResultParser = z.array(z.any()).transform((a) => a as Mixspace[]);

export const mixspaceGetOneParamsParser = z.object({
  [MIXSPACE_ID_PARAM_NAME]: mixspaceIdParser,
});

export const mixspaceGetOneResultParser = z.any(/* stub */).transform((o) => o as Mixspace);

export const mixspaceDeleteParamsParser = mixspaceGetOneParamsParser;

export const mixspaceAdminParser = z.string(); // TODO make sense of what we store here

export const makeMixspaceAdminsParser = <T extends string, P extends z.ZodType<T>>(p: P) => z.array(p);

export const makeMixspaceAdminsTraitParser = <T1, T extends ZodType<T1>>(a: T) =>
  z.object({
    admins: a,
  });

export const mixspaceAdminsTraitParser = makeMixspaceAdminsTraitParser(makeMixspaceAdminsParser(mixspaceAdminParser));

export const mixspaceCoreParser = mixspaceAdminsTraitParser.merge(
  z.object({
    accessThreshold: z.number().default(0), //default open access
    image: z
      .string()
      .url()
      .refine((s) => s.length > 0, {
        message: 'Field Required',
      }),
    items: z.array(
      z.object({
        edge: z.boolean().default(false),
        uuid: z.string(), //type for all uuid types
        x: z.number(),
        y: z.number(),
      })
    ),
    paymentWeights: z.object({}),
    reward: z.object({
      active: z.boolean().default(false), //we could maybe derive this bool from a combination of assets.length and !!(price > 0) below
      assets: z.array(z.string()),
      price: z.number().default(0),
    }),
    title: z.string().refine((s) => s.length > 0, {
      message: 'Field Required',
    }),
  })
);

export const mixspaceParser = mixspaceCoreParser.merge(
  z.object({
    id: mixspaceIdParser,
  })
);

export const mixspaceCreateInputParser = mixspaceCoreParser;
export const mixspaceCreateResponseParser = z.any(/*stub*/).transform((a) => a as MixspaceId);

export const mixspaceUpdateInputParser = mixspaceCreateInputParser.partial();
export const mixspaceUpdateParamsParser = mixspaceGetOneParamsParser;

export const mixspaceItemTypeParser = z.enum(MIXSPACE_ITEM_TYPES);

// further parser from item uuid
export const mixspaceItemUuidParserConverter = z.preprocess(
  (uuid) => {
    if (typeof uuid !== 'string') throw new Error('uuid must be a string');
    const [type, id] = uuid.split(UUID_SEPARATOR);
    return { type, id };
  },
  z.discriminatedUnion('type', [
    z.object({
      type: z.literal(MIXSPACE_ITEM_TYPE_APPLE),
      id: z.string(),
    }),
    z.object({
      type: z.literal(MIXSPACE_ITEM_TYPE_CHANNEL),
      id: channelIdParser,
    }),
  ])
);

==> currents-api-types-0.0.19.tgz: package/mixspace/parsers.ts <==
import { z, ZodType } from 'zod';
import { firestoreListParamsParser } from '../common/parsers/queryParams';
import { MIXSPACE_ID_PARAM_NAME } from './route.constants';
import { Mixspace } from './types';
import { MixspaceId } from './id.types';
import { UUID_SEPARATOR } from '../utils/uuid';
import { MIXSPACE_ITEM_TYPE_APPLE, MIXSPACE_ITEM_TYPE_CHANNEL, MIXSPACE_ITEM_TYPES } from './constants';
import { channelIdParser } from '../channel/parsers';
import { mixspaceIdParser } from './parsers.id';
import { firebaseAdminIdParser } from '../collective/parsers.admin';

export const mixspaceListQueryParser = firestoreListParamsParser
  .merge(
    z
      .object({
        adminId: firebaseAdminIdParser,
      })
      .partial()
  )
  .strict();
export const mixspaceListResultParser = z.array(z.any()).transform((a) => a as Mixspace[]);

export const mixspaceGetOneParamsParser = z.object({
  [MIXSPACE_ID_PARAM_NAME]: mixspaceIdParser,
});

export const mixspaceGetOneResultParser = z.any(/* stub */).transform((o) => o as Mixspace);

export const mixspaceDeleteParamsParser = mixspaceGetOneParamsParser;

export const mixspaceAdminParser = z.string(); // TODO make sense of what we store here

export const makeMixspaceAdminsParser = <T extends string, P extends z.ZodType<T>>(p: P) => z.array(p);

export const makeMixspaceAdminsTraitParser = <T1, T extends ZodType<T1>>(a: T) =>
  z.object({
    admins: a,
  });

export const mixspaceAdminsTraitParser = makeMixspaceAdminsTraitParser(makeMixspaceAdminsParser(mixspaceAdminParser));

export const mixspaceCoreParser = mixspaceAdminsTraitParser.merge(
  z.object({
    accessThreshold: z.number().default(0), //default open access
    image: z
      .string()
      .url()
      .refine((s) => s.length > 0, {
        message: 'Field Required',
      }),
    items: z.array(
      z.object({
        edge: z.boolean().default(false),
        uuid: z.string(), //type for all uuid types
        x: z.number(),
        y: z.number(),
      })
    ),
    paymentWeights: z.object({}),
    reward: z.object({
      active: z.boolean().default(false), //we could maybe derive this bool from a combination of assets.length and !!(price > 0) below
      assets: z.array(z.string()),
      price: z.number().default(0),
    }),
    title: z.string().refine((s) => s.length > 0, {
      message: 'Field Required',
    }),
  })
);

export const mixspaceParser = mixspaceCoreParser.merge(
  z.object({
    id: mixspaceIdParser,
  })
);

export const mixspaceCreateInputParser = mixspaceCoreParser;
export const mixspaceCreateResponseParser = z.any(/*stub*/).transform((a) => a as MixspaceId);

export const mixspaceUpdateInputParser = mixspaceCreateInputParser.partial();
export const mixspaceUpdateParamsParser = mixspaceGetOneParamsParser;

export const mixspaceItemTypeParser = z.enum(MIXSPACE_ITEM_TYPES);

// further parser from item uuid
export const mixspaceItemUuidParserConverter = z.preprocess(
  (uuid) => {
    if (typeof uuid !== 'string') throw new Error('uuid must be a string');
    const [type, id] = uuid.split(UUID_SEPARATOR);
    return { type, id };
  },
  z.discriminatedUnion('type', [
    z.object({
      type: z.literal(MIXSPACE_ITEM_TYPE_APPLE),
      id: z.string(),
    }),
    z.object({
      type: z.literal(MIXSPACE_ITEM_TYPE_CHANNEL),
      id: channelIdParser,
    }),
  ])
);
